``SubFigure`` default facecolor is now transparent
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Subfigures default facecolor changed to ``"none"``. Previously the default was
the value of ``figure.facecolor``.
